#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-store
version:              1.6.7
visibility:           public
id:                   x509-store-1.6.7-ISQ8liWEiGzKnOu2j78UBb
key:                  x509-store-1.6.7-ISQ8liWEiGzKnOu2j78UBb
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  aa4738219be361979b2e63950e210ac4
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-8.10.5/site-local/x509-store-1.6.7
library-dirs:         /usr/lib/ghc-8.10.5/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/x509-store-1.6.7
hs-libraries:         HSx509-store-1.6.7-ISQ8liWEiGzKnOu2j78UBb
depends:
    asn1-encoding-0.9.6-3xQoMgwk1EGDgUkApaPyF2
    asn1-types-0.3.4-8f2G3yyTw4VDZRkheuP3Dg base-4.14.2.0
    bytestring-0.10.12.0 containers-0.6.4.1
    cryptonite-0.29-KSQcZnQaH5M3lIm9Vzc7YS directory-1.3.6.0
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-2wQc93Rt7UuIV4uoSJd8MA
    x509-1.7.5-FcakXsO5AZG8CA3iSGWvZR

haddock-interfaces:   /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html:         /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

